@@ -10,11 +10,13 @@ import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeStore;
 import org.gcube.portlets.user.td.columnwidget.client.store.LocaleTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
+import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
-import org.gcube.portlets.user.td.gwtservice.shared.tr.DefNewColumn;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.TableType;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnMockUp;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.tr.column.ColumnTypeCode;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -48,6 +50,9 @@ import com.sencha.gxt.widget.core.client.form.TextField;
 import com.sencha.gxt.widget.core.client.info.Info;
 
 /**
+ * This Panel is used only with Codelist,
+ * so only with CODE,CODENAME,CODEDESCRIPTION,ANNOTATION columns
+ * 
  * 
  * @author "Giancarlo Panichi"
  * 
@@ -63,7 +68,6 @@ public class CreateDefColumnPanel extends FramedPanel {
 	protected EventBus eventBus;
 	protected CreateDefColumnDialog parent;
 	protected TableType tableType;
-	
 
 	protected ComboBox<ColumnTypeCodeElement> comboColumnTypeCode = null;
 	protected FieldLabel comboColumnTypeCodeLabel;
@@ -87,7 +91,8 @@ public class CreateDefColumnPanel extends FramedPanel {
 	public CreateDefColumnPanel(CreateDefColumnDialog parent,
 			TableType tableType, EventBus eventBus) {
 		super();
-		Log.debug("CreateDefColumnPanel[parent: "+parent+", tableType: "+tableType);
+		Log.debug("CreateDefColumnPanel[parent: " + parent + ", tableType: "
+				+ tableType);
 		this.parent = parent;
 		this.eventBus = eventBus;
 		this.tableType = tableType;
@@ -207,7 +212,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 		btnSave = new TextButton("Save");
 		btnSave.setIcon(ResourceBundle.INSTANCE.save());
 		btnSave.setIconAlign(IconAlign.RIGHT);
-		btnSave.setTitle("Save");
+		btnSave.setToolTip("Save");
 		btnSave.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -221,7 +226,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 		btnClose = new TextButton("Close");
 		btnClose.setIcon(ResourceBundle.INSTANCE.close());
 		btnClose.setIconAlign(IconAlign.RIGHT);
-		btnClose.setTitle("Close");
+		btnClose.setToolTip("Close");
 		btnClose.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -234,8 +239,9 @@ public class CreateDefColumnPanel extends FramedPanel {
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
 
-		flowButton.add(btnSave, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+		BoxLayoutData boxLayoutData = new BoxLayoutData(new Margins(2, 4, 2, 4));
+		flowButton.add(btnSave, boxLayoutData);
+		flowButton.add(btnClose, boxLayoutData);
 
 		VerticalLayoutContainer vPanel = new VerticalLayoutContainer();
 		vPanel.add(form, new VerticalLayoutData(1, -1));
@@ -247,6 +253,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 	}
 
 	protected void save() {
+		ColumnMockUp defNewColumn;
 		ColumnTypeCode currentType = null;
 		String localeName = null;
 
@@ -260,37 +267,62 @@ public class CreateDefColumnPanel extends FramedPanel {
 				+ ", locale: " + localeElement + ", default: " + valueDefault);
 		if (lab == null || lab.isEmpty()) {
 			UtilsGXT3.alert("Attention", "Add a label");
+			btnSave.enable();
 			return;
 		}
 
 		if (typeElement == null) {
 			UtilsGXT3.alert("Attention", "No type selected");
+			btnSave.enable();
 			return;
 		} else {
 			if (typeElement.getCode() == null) {
 				UtilsGXT3.alert("Attention", "No type selected");
+				btnSave.enable();
 				return;
 			} else {
 				currentType = typeElement.getCode();
 			}
 		}
-		if (currentType != null && currentType == ColumnTypeCode.CODENAME) {
+
+		switch (currentType) {
+		case ATTRIBUTE:
+			return;
+		case CODE:
+		case CODEDESCRIPTION:
+		case ANNOTATION:
+			defNewColumn = new ColumnMockUp(null, null, lab, currentType,
+					valueDefault);
+
+			break;
+		case CODENAME:
 			if (localeElement == null) {
 				UtilsGXT3.alert("Attention", "No locale selected");
+				btnSave.enable();
 				return;
 			} else {
 				if (localeElement.getLocaleName() == null
 						|| localeElement.getLocaleName().isEmpty()) {
 					UtilsGXT3.alert("Attention", "No locale selected");
+					btnSave.enable();
 					return;
 				} else {
 					localeName = localeElement.getLocaleName();
+					defNewColumn = new ColumnMockUp(null, null, lab,
+							currentType, localeName, valueDefault);
 				}
 			}
-		}
+			break;
+		case DIMENSION:
+			return;
+		case MEASURE:
+			return;
+		case TIMEDIMENSION:
+			return;
+		default:
+			return;
 
-		DefNewColumn defNewColumn = new DefNewColumn(lab, currentType,
-				localeName, valueDefault);
+		}
 		Log.debug("DefNewColumn:" + defNewColumn);
 		fireCompleted(defNewColumn);
 
@@ -375,9 +407,21 @@ public class CreateDefColumnPanel extends FramedPanel {
 							eventBus.fireEvent(new SessionExpiredEvent(
 									SessionExpiredType.EXPIREDONSERVER));
 						} else {
-							Log.debug(caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error retrieving locales",
-									caught.getLocalizedMessage());
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.debug(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving locales",
+											caught.getLocalizedMessage());
+								}
+							}
 						}
 					}
 
@@ -408,7 +452,7 @@ public class CreateDefColumnPanel extends FramedPanel {
 		listeners.remove(listener);
 	}
 
-	public void fireCompleted(DefNewColumn defNewColumn) {
+	public void fireCompleted(ColumnMockUp defNewColumn) {
 		for (CreateDefColumnListener listener : listeners)
 			listener.completedDefColumnCreation(defNewColumn);
 		close();
